@@ -27,7 +27,11 @@ def runtests(*test_args):
         test_args = ['django_mailbox']
     parent = dirname(abspath(__file__))
     sys.path.insert(0, parent)
-    runner = DjangoTestSuiteRunner(verbosity=1, interactive=True)
+    runner = DjangoTestSuiteRunner(
+        verbosity=1,
+        interactive=False,
+        failfast=False
+    )
     failures = runner.run_tests(test_args)
     sys.exit(failures)
 
